@@ -1,7 +1,7 @@
 /*
  * Function to create id partitions
  */
-CREATE FUNCTION create_partition_id(p_parent_table text, p_partition_ids bigint[], p_analyze boolean DEFAULT true) RETURNS boolean
+CREATE FUNCTION create_partition_id(p_parent_table text, p_partition_ids bigint[], p_analyze boolean DEFAULT true, p_debug boolean DEFAULT false) RETURNS boolean
     LANGUAGE plpgsql SECURITY DEFINER
     AS $$
 DECLARE
@@ -21,6 +21,7 @@ v_inherit_fk            boolean;
 v_job_id                bigint;
 v_jobmon                boolean;
 v_jobmon_schema         text;
+v_new_search_path       text := '@extschema@,pg_temp';
 v_old_search_path       text;
 v_parent_grant          record;
 v_parent_owner          text;
@@ -56,18 +57,23 @@ IF NOT FOUND THEN
     RAISE EXCEPTION 'ERROR: no config found for %', p_parent_table;
 END IF;
 
+SELECT current_setting('search_path') INTO v_old_search_path;
 IF v_jobmon THEN
-    SELECT nspname INTO v_jobmon_schema FROM pg_namespace n, pg_extension e WHERE e.extname = 'pg_jobmon' AND e.extnamespace = n.oid;
+    SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        SELECT current_setting('search_path') INTO v_old_search_path;
-        EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', '@extschema@,'||v_jobmon_schema, 'false');
+        v_new_search_path := '@extschema@,'||v_jobmon_schema||',pg_temp';
     END IF;
 END IF;
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
 
 -- Determine if this table is a child of a subpartition parent. If so, get limits of what child tables can be created based on parent suffix
 SELECT sub_min::bigint, sub_max::bigint INTO v_sub_id_min, v_sub_id_max FROM @extschema@.check_subpartition_limits(p_parent_table, 'id');
 
-SELECT tableowner, schemaname, tablename, tablespace INTO v_parent_owner, v_parent_schema, v_parent_tablename, v_parent_tablespace FROM pg_tables WHERE schemaname ||'.'|| tablename = p_parent_table;
+SELECT tableowner, schemaname, tablename, tablespace 
+INTO v_parent_owner, v_parent_schema, v_parent_tablename, v_parent_tablespace 
+FROM pg_catalog.pg_tables 
+WHERE schemaname = split_part(p_parent_table, '.', 1)::name
+AND tablename = split_part(p_parent_table, '.', 2)::name;
 
 IF v_jobmon_schema IS NOT NULL THEN
     v_job_id := add_job(format('PARTMAN CREATE TABLE: %s', p_parent_table));
@@ -83,7 +89,7 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
 
     v_partition_name := @extschema@.check_name_length(v_parent_tablename, v_id::text, TRUE);
     -- If child table already exists, skip creation
-    SELECT tablename INTO v_exists FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema AND tablename = v_partition_name;
+    SELECT tablename INTO v_exists FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema::name AND tablename = v_partition_name::name;
     IF v_exists IS NOT NULL THEN
         CONTINUE;
     END IF;
@@ -98,8 +104,8 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
     SELECT relpersistence INTO v_unlogged 
     FROM pg_catalog.pg_class c
     JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
-    WHERE c.relname = v_parent_tablename
-    AND n.nspname = v_parent_schema;
+    WHERE c.relname = v_parent_tablename::name
+    AND n.nspname = v_parent_schema::name;
     v_sql := 'CREATE';
     IF v_unlogged = 'u' THEN
         v_sql := v_sql || ' UNLOGGED';
@@ -112,8 +118,8 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
     SELECT relhasoids INTO v_hasoids 
     FROM pg_catalog.pg_class c
     JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
-    WHERE c.relname = v_parent_tablename
-    AND n.nspname = v_parent_schema;
+    WHERE c.relname = v_parent_tablename::name
+    AND n.nspname = v_parent_schema::name;
     IF v_hasoids IS TRUE THEN
         v_sql := v_sql || ' WITH (OIDS)';
     END IF;
@@ -131,45 +137,9 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
         , v_id + v_partition_interval);
     EXECUTE format('ALTER TABLE %I.%I INHERIT %I.%I', v_parent_schema, v_partition_name, v_parent_schema, v_parent_tablename);
 
-    FOR v_parent_grant IN 
-        SELECT array_agg(DISTINCT privilege_type::text ORDER BY privilege_type::text) AS types, grantee
-        FROM information_schema.table_privileges 
-        WHERE table_schema ||'.'|| table_name = p_parent_table
-        GROUP BY grantee 
-    LOOP
-        EXECUTE format('GRANT %s ON %I.%I TO %I'
-            , array_to_string(v_parent_grant.types, ',')
-            , v_parent_schema
-            , v_partition_name
-            , v_parent_grant.grantee);
-        SELECT string_agg(r, ',') INTO v_revoke FROM (SELECT unnest(v_all) AS r EXCEPT SELECT unnest(v_parent_grant.types)) x;
-        IF v_revoke IS NOT NULL THEN
-            EXECUTE format('REVOKE %s ON %I.%I FROM %I CASCADE'
-                , v_revoke
-                , v_parent_schema
-                , v_partition_name
-                , v_parent_grant.grantee);
-        END IF;
-        v_grantees := array_append(v_grantees, v_parent_grant.grantee::text);
-    END LOOP;
-    -- Revoke all privileges from roles that have none on the parent
-    IF v_grantees IS NOT NULL THEN
-        FOR v_row IN 
-            SELECT role FROM (
-                SELECT DISTINCT grantee::text AS role FROM information_schema.table_privileges WHERE table_schema = v_parent_schema AND table_name = v_partition_name
-                EXCEPT
-                SELECT unnest(v_grantees)) x
-        LOOP
-            IF v_row.role IS NOT NULL THEN
-                EXECUTE format('REVOKE ALL ON %I.%I FROM %I'
-                            , v_parent_schema
-                            , v_partition_name
-                            , v_row.role);
-            END IF;
-        END LOOP;
-    END IF;
+    PERFORM @extschema@.apply_privileges(v_parent_schema, v_parent_tablename, v_parent_schema, v_partition_name, v_job_id);
 
-    EXECUTE format('ALTER TABLE %I.%I OWNER TO %I', v_parent_schema, v_partition_name, v_parent_owner);
+    PERFORM @extschema@.apply_cluster(v_parent_schema, v_parent_tablename, v_parent_schema, v_partition_name);
 
     IF v_inherit_fk THEN
         PERFORM @extschema@.apply_foreign_keys(p_parent_table, v_parent_schema||'.'||v_partition_name, v_job_id);
@@ -183,21 +153,23 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
     -- This seemed easier than assigning a bunch of variables then doing an IF condition
     FOR v_row IN 
         SELECT sub_parent
-            , sub_control
             , sub_partition_type
+            , sub_control
             , sub_partition_interval
             , sub_constraint_cols
             , sub_premake
+            , sub_optimize_trigger
+            , sub_optimize_constraint
+            , sub_epoch
             , sub_inherit_fk
             , sub_retention
             , sub_retention_schema
             , sub_retention_keep_table
             , sub_retention_keep_index
             , sub_use_run_maintenance
-            , sub_epoch
-            , sub_optimize_trigger
-            , sub_optimize_constraint
+            , sub_infinite_time_partitions
             , sub_jobmon
+            , sub_trigger_exception_handling
         FROM @extschema@.part_config_sub
         WHERE sub_parent = p_parent_table
     LOOP
@@ -233,6 +205,8 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
             , retention_keep_index = v_row.sub_retention_keep_index
             , optimize_trigger = v_row.sub_optimize_trigger
             , optimize_constraint = v_row.sub_optimize_constraint
+            , infinite_time_partitions = v_row.sub_infinite_time_partitions
+            , trigger_exception_handling = v_row.sub_trigger_exception_handling
         WHERE parent_table = v_parent_schema||'.'||v_partition_name;
 
         IF v_jobmon_schema IS NOT NULL THEN
@@ -240,6 +214,9 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
         END IF;
 
     END LOOP; -- end sub partitioning LOOP
+    
+    -- Manage additonal constraints if set
+    PERFORM @extschema@.apply_constraints(p_parent_table, p_job_id := v_job_id, p_debug := p_debug);
 
     v_partition_created := true;
 
@@ -268,9 +245,7 @@ IF v_jobmon_schema IS NOT NULL THEN
     PERFORM close_job(v_job_id);
 END IF;
  
-IF v_jobmon_schema IS NOT NULL THEN
-    EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
-END IF;
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
 
 RETURN v_partition_created;
 
@@ -297,4 +272,3 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
-
