@@ -1,3 +1,6 @@
+/*
+ * Function to create partitioning trigger on parent table
+ */
 CREATE FUNCTION create_trigger(p_parent_table text) RETURNS void
     LANGUAGE plpgsql SECURITY DEFINER
     AS $$
@@ -5,6 +8,8 @@ DECLARE
 
 v_function_name         text;
 v_new_length            int;
+v_new_search_path       text := '@extschema@,pg_temp';
+v_old_search_path       text;
 v_parent_schema         text;
 v_parent_tablename      text;
 v_trig_name             text;
@@ -12,7 +17,13 @@ v_trig_sql              text;
 
 BEGIN
 
-SELECT schemaname, tablename INTO v_parent_schema, v_parent_tablename FROM pg_catalog.pg_tables WHERE schemaname ||'.'|| tablename = p_parent_table;
+SELECT current_setting('search_path') INTO v_old_search_path;
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
+
+SELECT schemaname, tablename INTO v_parent_schema, v_parent_tablename
+FROM pg_catalog.pg_tables
+WHERE schemaname = split_part(p_parent_table, '.', 1)::name
+AND tablename = split_part(p_parent_table, '.', 2)::name;
 v_trig_name := @extschema@.check_name_length(p_object_name := v_parent_tablename, p_suffix := '_part_trig'); 
 -- Ensure function name matches the naming pattern
 v_function_name := @extschema@.check_name_length(v_parent_tablename, '_part_trig_func', FALSE);
@@ -25,7 +36,8 @@ v_trig_sql := format('CREATE TRIGGER %I BEFORE INSERT ON %I.%I FOR EACH ROW EXEC
 
 EXECUTE v_trig_sql;
 
+EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
+
 END
 $$;
 
-
